@@ -7,6 +7,7 @@
 
 #include "rz_core.h"
 #include <QString>
+#include "RizinCpp.h"
 
 // Workaround for compile errors on Windows
 #ifdef Q_OS_WIN
@@ -14,16 +15,6 @@
 #    undef max
 #endif // Q_OS_WIN
 
-// Rizin list iteration macros
-#define CutterRListForeach(list, it, type, x)                                                      \
-    if (list)                                                                                      \
-        for (it = list->head; it && ((x = static_cast<type *>(it->data))); it = it->n)
-
-#define CutterRVectorForeach(vec, it, type)                                                        \
-    if ((vec) && (vec)->a)                                                                         \
-        for (it = (type *)(vec)->a;                                                                \
-             (char *)it != (char *)(vec)->a + ((vec)->len * (vec)->elem_size);                     \
-             it = (type *)((char *)it + (vec)->elem_size))
 
 // Global information for Cutter
 #define APPNAME "Cutter"
@@ -44,17 +35,17 @@ typedef ut64 RVA;
  */
 #define RVA_INVALID RVA_MAX
 
-inline QString RAddressString(RVA addr)
+inline QString RzAddressString(RVA addr)
 {
     return QString::asprintf("%#010llx", addr);
 }
 
-inline QString RSizeString(RVA size)
+inline QString RzSizeString(RVA size)
 {
     return QString::asprintf("%#llx", size);
 }
 
-inline QString RHexString(RVA size)
+inline QString RzHexString(RVA size)
 {
     return QString::asprintf("%#llx", size);
 }
